@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-download.h,v 1.7 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-download.h,v 1.7.2.2 2005/04/08 20:03:47 chpe Exp $
  */
 
 #ifndef EPHY_DOWNLOAD_H
@@ -62,9 +62,9 @@ struct _EphyDownloadClass
 	char * 		  (* get_target)           (EphyDownload *download);
 	char * 		  (* get_mime)             (EphyDownload *download);
 	int    		  (* get_percent)          (EphyDownload *download);
-	long   		  (* get_current_progress) (EphyDownload *download);
-	long   		  (* get_total_progress)   (EphyDownload *download);
-	long   		  (* get_elapsed_time)	   (EphyDownload *download);
+	gint64 		  (* get_current_progress) (EphyDownload *download);
+	gint64 		  (* get_total_progress)   (EphyDownload *download);
+	gint64 		  (* get_elapsed_time)	   (EphyDownload *download);
 	void   		  (* cancel)               (EphyDownload *download);
 	void   		  (* pause)                (EphyDownload *download);
 	void   		  (* resume)               (EphyDownload *download);
@@ -92,13 +92,13 @@ int                ephy_download_get_percent          (EphyDownload *download);
 
 EphyDownloadState  ephy_download_get_state	      (EphyDownload *download);	   
 
-long               ephy_download_get_current_progress (EphyDownload *download);
+gint64		   ephy_download_get_current_progress (EphyDownload *download);
 
-long               ephy_download_get_total_progress   (EphyDownload *download);
+gint64		   ephy_download_get_total_progress   (EphyDownload *download);
 
-long		   ephy_download_get_elapsed_time     (EphyDownload *download);
+gint64		   ephy_download_get_elapsed_time     (EphyDownload *download);
 
-long		   ephy_download_get_remaining_time   (EphyDownload *download);
+gint64		   ephy_download_get_remaining_time   (EphyDownload *download);
 
 void		   ephy_download_cancel	      	      (EphyDownload *download);
 
