@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-shell.c,v 1.27 2004/12/31 16:09:39 chpe Exp $
+ *  $Id: ephy-embed-shell.c,v 1.29.2.1 2005/07/04 12:14:55 chpe Exp $
  */
 
 #include "config.h"
@@ -43,6 +43,14 @@ struct _EphyEmbedShellPrivate
 	EphyEncodings *encodings;
 };
 
+enum
+{
+	PREPARE_CLOSE,
+	LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 static void ephy_embed_shell_class_init	(EphyEmbedShellClass *klass);
 static void ephy_embed_shell_init	(EphyEmbedShell *shell);
 
@@ -83,13 +91,13 @@ ephy_embed_shell_finalize (GObject *object)
 {
 	EphyEmbedShell *shell = EPHY_EMBED_SHELL (object);
 
-	LOG ("Unref history")
+	LOG ("Unref history");
 	if (shell->priv->global_history)
 	{
 		g_object_unref (shell->priv->global_history);
 	}
 
-	LOG ("Unref downloader")
+	LOG ("Unref downloader");
 	if (shell->priv->downloader_view)
 	{
 		g_object_remove_weak_pointer
@@ -98,19 +106,19 @@ ephy_embed_shell_finalize (GObject *object)
 		g_object_unref (shell->priv->downloader_view);
 	}
 
-	LOG ("Unref favicon cache")
+	LOG ("Unref favicon cache");
 	if (shell->priv->favicon_cache)
 	{
 		g_object_unref (G_OBJECT (shell->priv->favicon_cache));
 	}
 
-	LOG ("Unref encodings")
+	LOG ("Unref encodings");
 	if (shell->priv->encodings)
 	{
 		g_object_unref (G_OBJECT (shell->priv->encodings));
 	}
 
-	LOG ("Unref embed single")
+	LOG ("Unref embed single");
 	if (shell->priv->embed_single)
 	{
 		g_object_unref (G_OBJECT (shell->priv->embed_single));
@@ -169,8 +177,8 @@ ephy_embed_shell_get_downloader_view (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->downloader_view);
 }
 
-GObject *
-ephy_embed_shell_get_embed_single (EphyEmbedShell *shell)
+static GObject *
+impl_get_embed_single (EphyEmbedShell *shell)
 {
 	g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
 
@@ -183,6 +191,14 @@ ephy_embed_shell_get_embed_single (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->embed_single);
 }
 
+GObject *
+ephy_embed_shell_get_embed_single (EphyEmbedShell *shell)
+{
+	EphyEmbedShellClass *klass = EPHY_EMBED_SHELL_GET_CLASS (shell);
+
+	return klass->get_embed_single (shell);
+}
+
 GObject *
 ephy_embed_shell_get_encodings (EphyEmbedShell *shell)
 {
@@ -196,6 +212,12 @@ ephy_embed_shell_get_encodings (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->encodings);
 }
 
+void
+ephy_embed_shell_prepare_close (EphyEmbedShell *shell)
+{
+	g_signal_emit (shell, signals[PREPARE_CLOSE], 0);
+}
+
 static void
 ephy_embed_shell_init (EphyEmbedShell *shell)
 {
@@ -215,5 +237,24 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
 
 	object_class->finalize = ephy_embed_shell_finalize;
 
+	klass->get_embed_single = impl_get_embed_single;
+
+/**
+ * EphyEmbed::prepare-close:
+ * @shell:
+ * 
+ * The ::prepare-close signal is emitted when epiphany is preparing to
+ * quit on command from the session manager. You can use it when you need
+ * to do something special (shut down a service, for example).
+ **/
+	signals[PREPARE_CLOSE] =
+		g_signal_new ("prepare-close",
+			      EPHY_TYPE_EMBED_SHELL,
+			      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedShellClass, prepare_close),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
+	
 	g_type_class_add_private (object_class, sizeof (EphyEmbedShellPrivate));
 }
