@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.75 2005/01/24 13:43:58 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.76.2.7 2005/06/05 09:36:06 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -70,9 +70,9 @@
 #include "nsIDOMWindow2.h"
 #include "nsIDOMDocumentView.h"
 #include "nsIDOMAbstractView.h"
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include "nsEmbedString.h"
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include "nsMemory.h"
 #include "nsIChannel.h"
 #include "nsIScriptSecurityManager.h"
@@ -117,12 +117,12 @@ static PRUnichar DOMModalDialogClosed[] = { 'D', 'O', 'M', 'M', 'o', 'd', 'a',
 EphyEventListener::EphyEventListener()
 : mOwner(nsnull)
 {
-	LOG ("EphyEventListener ctor (%p)", this)
+	LOG ("EphyEventListener ctor (%p)", this);
 }
 
 EphyEventListener::~EphyEventListener()
 {
-	LOG ("EphyEventListener dtor (%p)", this)
+	LOG ("EphyEventListener dtor (%p)", this);
 }
 
 NS_IMPL_ISUPPORTS1(EphyEventListener, nsIDOMEventListener)
@@ -137,6 +137,15 @@ EphyEventListener::Init (EphyBrowser *aOwner)
 NS_IMETHODIMP
 EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 {
+#ifdef MOZ_NSIDOMNSEVENT_GETISTRUSTED
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aDOMEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
+#endif /* MOZ_NSIDOMNSEVENT_GETISTRUSTED */
+
 	nsCOMPtr<nsIDOMEventTarget> eventTarget;
 	aDOMEvent->GetTarget(getter_AddRefs(eventTarget));
 
@@ -254,9 +263,17 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 		if (!shouldLoad) return NS_OK;
 #endif
+		
+		/* Hide password part */
+		nsEmbedCString user;
+		favUri->GetUsername (user);
+		favUri->SetUserPass (user);
+
+		nsEmbedCString favUriSpec;
+		favUri->GetSpec (favUriSpec);
 
 		/* ok, we accept this as a valid favicon for this site */
-		g_signal_emit_by_name (mOwner->mEmbed, "ge_favicon", faviconUrl.get());
+		g_signal_emit_by_name (mOwner->mEmbed, "ge_favicon", favUriSpec.get());
 	}
 
 	return NS_OK;
@@ -265,6 +282,15 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 NS_IMETHODIMP
 EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 {
+#ifdef MOZ_NSIDOMNSEVENT_GETISTRUSTED
+	/* make sure the event is trusted */
+	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aDOMEvent));
+	NS_ENSURE_TRUE (nsEvent, NS_ERROR_FAILURE);
+	PRBool isTrusted = PR_FALSE;
+	nsEvent->GetIsTrusted (&isTrusted);
+	if (!isTrusted) return NS_OK;
+#endif /* MOZ_NSIDOMNSEVENT_GETISTRUSTED */
+
 	nsCOMPtr<nsIDOMPopupBlockedEvent> popupEvent =
 		do_QueryInterface (aDOMEvent);
 	NS_ENSURE_TRUE (popupEvent, NS_ERROR_FAILURE);
@@ -341,12 +367,12 @@ EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 EphyContextMenuListener::EphyContextMenuListener()
 : mOwner(nsnull)
 {
-	LOG ("EphyContextMenuListener ctor (%p)", this)
+	LOG ("EphyContextMenuListener ctor (%p)", this);
 }
 
 EphyContextMenuListener::~EphyContextMenuListener()
 {
-	LOG ("EphyContextMenuListener dtor (%p)", this)
+	LOG ("EphyContextMenuListener dtor (%p)", this);
 }
 
 NS_IMPL_ISUPPORTS1(EphyContextMenuListener, nsIDOMContextMenuListener)
@@ -438,12 +464,12 @@ EphyBrowser::EphyBrowser ()
 , mContextMenuListener(nsnull)
 , mInitialized(PR_FALSE)
 {
-	LOG ("EphyBrowser ctor (%p)", this)
+	LOG ("EphyBrowser ctor (%p)", this);
 }
 
 EphyBrowser::~EphyBrowser ()
 {
-	LOG ("EphyBrowser dtor (%p)", this)
+	LOG ("EphyBrowser dtor (%p)", this);
 }
 
 nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
@@ -496,6 +522,13 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 #ifdef HAVE_MOZILLA_PSM
+#ifdef HAVE_GECKO_1_8
+	nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	rv = docShell->GetSecurityUI (getter_AddRefs (mSecurityInfo));
+	NS_ENSURE_SUCCESS (rv, rv);
+#else
 	/* FIXME: mozilla sucks! nsWebBrowser already has an instance of this,
 	 * but we cannot get to it!
 	 * See https://bugzilla.mozilla.org/show_bug.cgi?id=94974
@@ -532,11 +565,12 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 			NS_ENSURE_SUCCESS (rv, rv);
 		}
 	}
+#endif /* HAVE_GECKO_1_8 */
 	if (!mSecurityInfo)
 	{
-		g_warning ("Failed to instantiate nsISecureBrowserUI!\n");
+		g_warning ("Failed to get nsISecureBrowserUI!\n");
  	}
-#endif
+#endif /* HAVE_MOZILLA_PSM */
 
 	mInitialized = PR_TRUE;
 
@@ -936,48 +970,38 @@ nsresult EphyBrowser::GetDOMWindow (nsIDOMWindow **aDOMWindow)
 	return NS_OK;
 }
 
-nsresult EphyBrowser::GetDocumentUrl (nsACString &url)
+nsresult EphyBrowser::GetDocumentURI (nsIURI **aURI)
 {
+	if (!mDOMWindow) return NS_ERROR_NOT_INITIALIZED;
+
 	nsresult rv;
-
-	NS_ENSURE_TRUE (mDOMWindow, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOMDocument> DOMDocument;
-	mDOMWindow->GetDocument (getter_AddRefs(DOMDocument));
-	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOM3Document> doc = do_QueryInterface(DOMDocument);
-	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
-
-	nsEmbedString docURI;
-	rv = doc->GetDocumentURI (docURI);
+	nsCOMPtr<nsIWebNavigation> webNav (do_GetInterface (mDOMWindow, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	NS_UTF16ToCString (docURI, NS_CSTRING_ENCODING_UTF8, url);
-
-	return NS_OK;
+	return webNav->GetCurrentURI (aURI);
 }
 
-nsresult EphyBrowser::GetTargetDocumentUrl (nsACString &url)
+nsresult EphyBrowser::GetTargetDocumentURI (nsIURI **aURI)
 {
+	if (!mWebBrowser) return NS_ERROR_NOT_INITIALIZED;
+
+        nsCOMPtr<nsIDOMDocument> domDoc;
+	GetTargetDocument (getter_AddRefs(domDoc));
+	NS_ENSURE_TRUE (domDoc, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMDocumentView> docView (do_QueryInterface (domDoc));
+	NS_ENSURE_TRUE (docView, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMAbstractView> abstractView;
+	docView->GetDefaultView (getter_AddRefs (abstractView));
+	NS_ENSURE_TRUE (abstractView, NS_ERROR_FAILURE);
+	/* the abstract view is really the DOM window */
+
 	nsresult rv;
-
-	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
-
-        nsCOMPtr<nsIDOMDocument> DOMDocument;
-	GetTargetDocument (getter_AddRefs(DOMDocument));
-	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDOM3Document> doc = do_QueryInterface(DOMDocument);
-	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
-
-	nsEmbedString docURI;
-	rv = doc->GetDocumentURI (docURI);
+	nsCOMPtr<nsIWebNavigation> webNav (do_GetInterface (abstractView, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	NS_UTF16ToCString (docURI, NS_CSTRING_ENCODING_UTF8, url);
-
-	return NS_OK;
+	return webNav->GetCurrentURI (aURI);
 }
 
 nsresult EphyBrowser::ForceEncoding (const char *encoding) 
