@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: mozilla-download.cpp,v 1.19 2005/01/28 22:23:38 chpe Exp $
+ * $Id: mozilla-download.cpp,v 1.19.2.4 2005/04/26 12:02:28 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -23,12 +23,14 @@
 #include "config.h"
 
 #include "mozilla-download.h"
+#include "MozDownload.h"
 
 #include "ephy-debug.h"
 
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
+#include <nsILocalFile.h>
 #include <nsMemory.h>
 
 static void mozilla_download_class_init	(MozillaDownloadClass *klass);
@@ -41,7 +43,7 @@ enum
 	PROP_MOZDOWNLOAD
 };
 
-struct MozillaDownloadPrivate
+struct _MozillaDownloadPrivate
 {
 	MozDownload *moz_download;
 };
@@ -109,11 +111,11 @@ impl_get_source (EphyDownload *download)
 	return g_strdup (spec.get());
 }
 
-static long
+static gint64
 impl_get_current_progress (EphyDownload *download)
 {
 	MozDownload *mozDownload;
-	PRInt32 progress;
+	PRInt64 progress;
 
 	mozDownload = MOZILLA_DOWNLOAD (download)->priv->moz_download;
 
@@ -135,11 +137,11 @@ impl_get_state (EphyDownload *download)
 	return state;
 }
 
-static long
+static gint64
 impl_get_total_progress (EphyDownload *download)
 {
 	MozDownload *mozDownload;
-	PRInt32 progress;
+	PRInt64 progress;
 
 	mozDownload = MOZILLA_DOWNLOAD (download)->priv->moz_download;
 
@@ -161,7 +163,7 @@ impl_get_percent (EphyDownload *download)
 	return percent;
 }
 
-static long
+static gint64
 impl_get_elapsed_time (EphyDownload *download)
 {
 	MozDownload *mozDownload;
@@ -186,7 +188,7 @@ impl_get_mime (EphyDownload *download)
 	mozDownload->GetMIMEInfo (getter_AddRefs(mime));
         if (!mime) return g_strdup ("application/octet-stream");
 
-#ifdef MOZ_NSIMIMEINFO_NSACSTRING_
+#ifdef HAVE_GECKO_1_8
         mime->GetMIMEType(mimeType);
 #else
 	char *tmp = nsnull;
