@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.101 2005/01/31 13:53:05 chpe Exp $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -36,9 +36,9 @@
 #include "EphyUtils.h"
 
 #include <gtkmozembed.h>
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsMemory.h>
 #include <nsIURI.h>
 #include <nsIRequest.h>
@@ -227,6 +227,8 @@ static GObject *
 mozilla_embed_constructor (GType type, guint n_construct_properties,
 			   GObjectConstructParam *construct_params)
 {
+	g_object_ref (embed_shell);
+
 	/* we depend on single because of mozilla initialization */
 	ephy_embed_shell_get_embed_single (embed_shell);
 
@@ -312,6 +314,8 @@ mozilla_embed_finalize (GObject *object)
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
+
+	g_object_unref (embed_shell);
 }
 
 static void
@@ -479,24 +483,30 @@ impl_get_location (EphyEmbed *embed,
                    gboolean toplevel)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-	char *l;
 	nsresult rv;
-	nsEmbedCString url;
 
+	nsCOMPtr<nsIURI> uri;
 	if (toplevel)
 	{
-		rv = mpriv->browser->GetDocumentUrl (url);
-		l = (NS_SUCCEEDED (rv) && url.Length()) ?
-		     g_strdup (url.get()) : NULL;	   	
+		rv = mpriv->browser->GetDocumentURI (getter_AddRefs (uri));
 	}
 	else
 	{
-		rv = mpriv->browser->GetTargetDocumentUrl (url);
-		l = (NS_SUCCEEDED (rv) && url.Length()) ?
-		     g_strdup (url.get()) : NULL;	   	
+		rv = mpriv->browser->GetTargetDocumentURI (getter_AddRefs (uri));
 	}
 
-	return l;
+	if (NS_FAILED (rv)) return NULL;
+
+	nsCOMPtr<nsIURI> furi;
+	rv = uri->Clone (getter_AddRefs (furi));
+	if (NS_FAILED (rv)) return NULL;
+
+	furi->SetPassword (nsEmbedCString());
+
+	nsEmbedCString url;
+	furi->GetSpec (url);
+
+	return url.Length() ? g_strdup (url.get()) : NULL;
 }
 
 static void
@@ -1120,7 +1130,16 @@ _mozilla_embed_new_xul_dialog (void)
 {
 	GtkWidget *window, *embed;
 
+	g_object_ref (embed_shell);
+
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	g_object_set_data_full (G_OBJECT (window), "EmbedShellRef",
+			        embed_shell,
+				(GDestroyNotify) g_object_unref);
+	g_signal_connect_object (embed_shell, "prepare_close",
+				 G_CALLBACK (gtk_widget_destroy), window,
+				 (GConnectFlags) G_CONNECT_SWAPPED);
+
 	embed = gtk_moz_embed_new ();
 	gtk_widget_show (embed);
 	gtk_container_add (GTK_CONTAINER (window), embed);
