@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.15 2004/12/18 21:51:47 chpe Exp $
+ *  $Id: ephy-gui.h,v 1.17 2005/02/26 22:01:48 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
@@ -68,6 +68,12 @@ void		ephy_gui_help				 (GtkWindow *parent,
 							  const char *file_name,
 							  const char *link_id);
 
+void		ephy_gui_window_update_user_time	 (GtkWidget *window,
+							  guint32 user_time);
+
+void		ephy_gui_window_present			 (GtkWindow *window,
+							  guint32 user_time);
+
 G_END_DECLS
 
 #endif
