@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-action.c,v 1.10 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-zoom-action.c,v 1.11 2005/01/08 19:41:47 chpe Exp $
  */
 
 #include "config.h"
@@ -34,7 +34,7 @@
 
 #define EPHY_ZOOM_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ZOOM_ACTION, EphyZoomActionPrivate))
 
-struct EphyZoomActionPrivate
+struct _EphyZoomActionPrivate
 {
 	float zoom;
 };
