@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.120 2005/02/21 11:23:21 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -472,8 +472,13 @@ ephy_shell_startup (EphyShell *shell,
 				       "from Bonobo when attempting to locate the automation "
 				       "object."));
 			automation = NULL;
+			goto done;
 		}
-		else if (flags & EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR)
+
+		/* init the session manager up here so we can quit while the resume dialogue is on */
+		gnome_session_init (shell);
+
+		if (flags & EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR)
 		{
 			GNOME_EphyAutomation_openBookmarksEditorWithStartupId
 				(automation, user_time, &ev);
@@ -501,14 +506,10 @@ ephy_shell_startup (EphyShell *shell,
 				   flags & EPHY_SHELL_STARTUP_FULLSCREEN);
 		}
 
-		if (automation)
-		{
-			bonobo_object_release_unref (automation, &ev);
-		}
-
-		gnome_session_init (shell);
+		bonobo_object_release_unref (automation, &ev);
 	}
 
+done:
 	CORBA_exception_free (&ev);
 	gdk_notify_startup_complete ();
 
